Summary: The Linux kernel (the core of the Linux operating system)

# versioning hell
%define buildsmp 1
%define sublevel 20
%define kversion 2.4.%{sublevel}
%define kslnk linux
%define _bootdir /boot

# disable build root strip policy
%define __spec_install_post /usr/lib/rpm/brp-compress || :

Name: kernel-benh
Version: %{kversion}
Release: 9mdk 
%define KVERREL %{PACKAGE_VERSION}-benh-%{PACKAGE_RELEASE}
Copyright: GPL
Group: System Environment/Kernel
ExclusiveArch: ppc
ExclusiveOS: Linux
Provides: module-info, kernel = %{version}
Autoreqprov: no
Prereq: fileutils, modutils >= 2.3.14
Requires: mkinitrd >= 3.0.5
Source0: linux-%{kversion}.tar.bz2

Source11: module-info
Source14: kernel-2.4-BuildASM.sh

Source20: kernel-%{kversion}-ppc.config
Source21: kernel-%{kversion}-ppc-smp.config

# Patches 0 through 9 are meant for patches that absolutely need to
# be first.

Patch1:  linux-2.4.0-isdnbsdcomp.patch.bz2
Patch2:  linux-2.4.0-xmonreadme.patch.bz2
Patch3:  linux-2.4.2-4port_ether.patch.bz2
Patch5:  linux-2.4.18-macserial.patch.bz2

# FILESYSTEMS: patches 40 through 49
Patch40: linux-2.4-includefs.patch.bz2

# VIDEO: patches 50 through 59
Patch50: linux-2.4.5-vgacon.patch.bz2
Patch51: linux-2.4.8-macmodes.patch.bz2
Patch52: new_sleep.diff.bz2

# Fixes
Patch60: kernel-2.4.20-xfs-sunrpc-symbols.patch.bz2

# IP Virtual Server
Patch70: linux-2.4.19-ipvs-1.0.7.patch.bz2

# Mandrake Patches: Start at 100
Patch100: FS60-2_mediactl.patch.bz2
Patch101: FS70-7_supermount.patch.bz2
Patch102: CD01_bootlogo_with_version.patch.bz2
Patch103: CD04_default_logo.patch.bz2
Patch104: FX01_xfs-1.2pre3.patch.bz2
Patch105: FX02-4_core-xfs-1.2pre3.patch.bz2
Patch106: FS50-2_new_stat.patch.bz2
Patch107: FB02_autoload_freevxfs.patch.bz2
Patch108: FS40_device.patch.bz2
Patch109: FS10_readlink.patch.bz2
Patch110: FS20-2_mount.patch.bz2
Patch111: FS30_lseek.patch.bz2
Patch112: kernel-2.4_ptrace.patch.bz2

BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
BenH based kernel package for Mandrake PPC

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: module-info, kernel = %{version}
Prereq: modutils >= 2.3.14, fileutils
Requires: mkinitrd >= 3.0.5

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs, although it should
work fine on single-CPU boxes.

Install the kernel-smp package if your machine uses two or more CPUs.

%prep

%setup -q {name}-%{version} -c
%patch1 -p1
%patch2 -p1
#%patch3 -p1
%patch5 -p1

%patch40 -p1

%patch50 -p1
%patch51 -p1

# Fixes
%patch60 -p1 -b .symbols

# Mandrake Patches
%patch100 -p1 -b .mediactl
%patch101 -p1 -b .supermount
%patch102 -p1 -b .bootlogo
%patch103 -p1 -b .def_logo
%patch104 -p1 -b .xfs
%patch105 -p1 -b .core_xfs
%patch106 -p1 -b .new_stat
%patch107 -p1 -b .freevxfs
%patch108 -p1 -b .devices
%patch109 -p1 -b .readlink
%patch110 -p1 -b .mount
%patch111 -p1 -b .lseek

%patch70 -p1 -b .ipvs

# new ati sleep code
%patch52 -p1 -b .sleep

#ptrace security patch
%patch112 -p1 -b .ptrace

mkdir configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-%{_target_cpu}*.config configs

# make sure the kernel has the sublevel we know it has...
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name "*.orig" -exec rm -fv {} \;

chmod 755 arch/*/kernel/check_asm.sh

###
### build
###
%build

# why glibc doesn't parse this instead of cpuinfo I don't know
if [ -f /proc/stat ]; then
  NRPROC=`egrep -c "^cpu[0-9]+" /proc/stat || :` 
  if [ $NRPROC -eq 0 ] ; then
  	NRPROC=1
  fi
else
  NRPROC=1
fi

DependKernel() {
    # is this a special kernel we want to build?
    if [ -n "$2" ] ; then
	Config=$1-$2
	KernelVer=%{version}-benh-%{release}$2
	echo MAKE DEPEND FOR $2 $1 KERNEL...
    else
	Config=$1
	KernelVer=%{version}-benh-%{release}
	echo MAKE DEPEND FOR up $1 KERNEL...
    fi
    make -s mrproper
    cp configs/kernel-%{kversion}-$Config.config .config
    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -benh-%{release}$2/" Makefile
    make -s oldconfig
    make -s dep
    make -s include/linux/version.h 
}

BuildKernel() {
    if [ -n "$1" ] ; then
	Config=%{_target_cpu}-$1
	KernelVer=%{version}-%{release}$1
	DependKernel %{_target_cpu} $1
	echo BUILDING A KERNEL FOR $1...
    else
	Config=%{_target_cpu}
	KernelVer=%{version}-%{release}
	DependKernel %{_target_cpu}
	echo BUILDING THE NORMAL KERNEL...
    fi

    make -s -j $NRPROC vmlinux 
    make -j $NRPROC modules
    # first make sure we are not loosing any .ver files to make mrporper's
    # removal of zero sized files.
    find include/linux/modules -size 0 | while read file ; do \
	echo > $file
    done
    # Start installing stuff
    mkdir -p $RPM_BUILD_ROOT/boot
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 $RPM_SOURCE_DIR/module-info $RPM_BUILD_ROOT/boot/module-info-$KernelVer

    # optional installs (depending on the arch built)
    [ -f vmlinux ] && install -m 755 vmlinux $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
}

###
# DO it...
###

rm -rf $RPM_BUILD_ROOT

%if %{buildsmp}
# SMP-ENABLED KERNEL
BuildKernel smp
%endif

# NORMAL KERNEL
BuildKernel

###
### install
###

%install

#cd linux
mkdir -p $RPM_BUILD_ROOT/boot

# other tools

for i in $RPM_BUILD_ROOT/lib/modules/*; do
  rm -f $i/modules.dep $i/modules.*map $i/modules.*string
done

# remove uselesss symlink - not doing kernel-source

find $RPM_BUILD_ROOT/lib/modules -name build | xargs rm -f

###
### clean
###

%clean
#rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null
exit 0

%post 
depmod -a -e -F /boot/System.map-%{KVERREL} %{KVERREL}
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
              /sbin/installkernel -a -c %{KVERREL}
fi

%post smp
depmod -a -e -F /boot/System.map-%{KVERREL}smp %{KVERREL}smp
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
              /sbin/installkernel -a -c %{KVERREL}smp
fi

# Allow clean removal of modules directory
%preun 
rm -f /lib/modules/%{KVERREL}/modules.dep
rm -f /lib/modules/%{KVERREL}/modules.*map
rm -f /lib/modules/%{KVERREL}/modules.*string

REMOVE=
if [ -f /etc/sysconfig/system ];then
                source /etc/sysconfig/system
                [[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
                source /etc/sysconfig/installkernel
                [[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
                [[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}

exit 0

%preun smp
rm -f /lib/modules/%{KVERREL}smp/modules.dep
rm -f /lib/modules/%{KVERREL}smp/modules.*map
rm -f /lib/modules/%{KVERREL}smp/modules.*string

REMOVE=
if [ -f /etc/sysconfig/system ];then
                source /etc/sysconfig/system
                [[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
                source /etc/sysconfig/installkernel
                [[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
                [[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}smp

exit 0

###
### file lists
###

%files 
%defattr(-,root,root)
/boot/vmlinuz-%{KVERREL}
/boot/module-info-%{KVERREL}
/boot/System.map-%{KVERREL}
%dir /lib/modules
/lib/modules/%{KVERREL}

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/boot/vmlinuz-%{KVERREL}smp
/boot/module-info-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
%dir /lib/modules
/lib/modules/%{KVERREL}smp
%endif

%changelog
* Wed Mar 19 2003 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-9mdk
- ptrace security fix (patch112)

* Sat Mar 15 2003 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-8mdk
- Ben's new ATI sleep code (patch52), still -ben8

* Mon Mar 10 2003 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-7mdk
- rsync -ben8

* Mon Mar 03 2003 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-6mdk
- rsync -ben7

* Thu Feb 13 2003 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-5mdk
- drop gatos patches (patch 52) - breaks sleep
- rsync -ben5, CONFIG_CPU_FREQ enabled

* Wed Jan 29 2003 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-4mdk
- gatos drm patches (patch 52)
- ipvs patches (patch 70)
- resync benh source from cvs -ben4
- remove useless "build" symlink

* Mon Jan 27 2003 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-3mdk
- new rsync of benh tree, rework patch105

* Mon Dec 16 2002 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-2mdk
- add -e to depmod to show unresolved symbols in %%post
- fix unresolved symbols in sunrpc.o
- add Mandrake supermount(not working yet), logo, xfs patches
- bzip2 all patches

* Tue Dec 10 2002 Stew Benedict <sbenedict@mandrakesoft.com> 2.4.20-1mdk
- starting point for benh+mdk - based on ydl spec 
- drop briq/ans
- rc4-ben0

* Tue Jun 04 2002 Dan Burcaw <dburcaw@terrasoftsolutions.com>
- pre10 for Dayton

